/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-10-0/engines/cine/rel.h $
 * $Id: rel.h 27024 2007-05-30 21:56:52Z fingolfin $
 *
 */

#ifndef CINE_REL_H
#define CINE_REL_H

namespace Cine {

struct RelObjectScript {
	byte *data;
	uint16 size;
	uint16 obj1Param1;
	uint16 obj1Param2;
	uint16 obj2Param;
};

#define NUM_MAX_REL 255

extern RelObjectScript relTable[NUM_MAX_REL];

void releaseObjectScripts(void);
void resetObjectScriptHead(void);

void loadRel(char *pRelName);

} // End of namespace Cine

#endif
